==> firefox-7.0.1.en-US.opensolaris-sparc.tar.bz2: jsloader/resource/gre/components/Weave.js <==
          resource:///components/Weave.js         
           u                                  ; 5   Q; 5  Q; 5  Q;  = : Q;  = 	: Q;  = 
: Q ; Y ;  
= : ] ;  Z  >; 5 ^?; 5 ^\: ]   \6 Q ; Y ;  
= : ] ;  Z  >; 5 ^?; 5 ^\: ]     \6 QZ  >; ^?; ^\ Q;  ; :  Q   &˸i&c3c3c3*cf	cf	cf	. 0cf	4c`ce7`>LNcf	Rc`ceUY`Egi0cf	3             Jb۬ӷe `              F  P   C c 
   C o m p o n e n t s    c l a s s e s      C i 
   i n t e r f a c e s    C u    u t i l s      i m p o r t %   r e s o u r c e : / / g r e / m o d u l e s / X P C O M U t i l s . j s m   #   r e s o u r c e : / / g r e / m o d u l e s / S e r v i c e s . j s m   $   r e s o u r c e : / / g r e / m o d u l e s / F i l e U t i l s . j s m    W e a v e S e r v i c e 	   p r o t o t y p e      I D &   { 7 4 b 8 9 f b 0 - f 2 0 0 - 4 a e 8 - a 3 e c - d d 1 6 4 1 1 7 f 6 d e }    c l a s s I D   
   X P C O M U t i l s 
   g e n e r a t e Q I    n s I O b s e r v e r      n s I S u p p o r t s W e a k R e f e r e n c e    Q u e r y I n t e r f a c e    o b s e r v e   
   A b o u t W e a v e L o g   &   { d 2 8 f 8 a 0 b - 9 5 d a - 4 8 f 4 - b 7 1 2 - c a f 3 7 0 9 7 b e 4 1 }    n s I A b o u t M o d u l e    g e t U R I F l a g s   
   n e w C h a n n e l 
   c o m p o n e n t s    N S G e t F a c t o r y    g e n e r a t e N S G e t F a c t o r y           W e a v e S e r v i c e                                                   AA6  Q b .        Jb۬ӷe `              F     w r a p p e d J S O b j e c t             B S S _ _ o b s e r v e 	              s u b j e c t      t o p i c      d a t a              8                           T G y    
  8;  5  ; 5 : W  QV   A= C: Q G  A;  5  	; 5 
: 6 QA5  Y     \X'; 5 
5 
: Q         y ͸:cccc3c`AdcfccacʸHfcc ˰ 7        Jb۬ӷe `              F  8   C c    @ m o z i l l a . o r g / o b s e r v e r - s e r v i c e ; 1   
   g e t S e r v i c e    C i    n s I O b s e r v e r S e r v i c e    a d d O b s e r v e r      f i n a l - u i - s t a r t u p    t i m e r      @ m o z i l l a . o r g / t i m e r ; 1    c r e a t e I n s t a n c e    n s I T i m e r    i n i t W i t h C a l l b a c k    n o t i f y 
   T Y P E _ O N E _ S H O T            o s         	          +                                        ;   = : Q; 5  :  ; 5  
; 5 Q cf	ccc	fc  C        Jb۬ӷe `              F     C u    i m p o r t     r e s o u r c e : / / s e r v i c e s - s y n c / m a i n . j s    W e a v e      S t a t u s 
   c h e c k S e t u p    C L I E N T _ N O T _ C O N F I G U R E D      S e r v i c e         a p p - s t a r t u p         f i n a l - u i - s t a r t u p        
   A b o u t W e a v e L o g                                                             N         Jb۬ӷe `              F   d        	              a U R I                                          >    U        Jb۬ӷe `              F  l        	             a U R I    d i r      u r i      c h a n n e l      s s m   	   p r i n c i p a l               6                           ;   = Z  >= ^?= ^\C: W  Q; 5  V  : W Q; 5  V : W QV T  6 	Q; 
5  ; 
5 : W QV  V : W QV V 6 QV    c`3 ccf3 ccf3 facccc3 cf	3 f   Y        Jb۬ӷe `              F  	   F i l e U t i l s      g e t D i r    P r o f D      w e a v e      l o g s    S e r v i c e s    i o 
   n e w F i l e U R I    n e w C h a n n e l F r o m U R I      o r i g i n a l U R I      C c $   @ m o z i l l a . o r g / s c r i p t s e c u r i t y m a n a g e r ; 1 
   g e t S e r v i c e    C i    n s I S c r i p t S e c u r i t y M a n a g e r    g e t C o d e b a s e P r i n c i p a l    o w n e r   

==> firefox-8.0.1.en-US.opensolaris-sparc.tar.bz2: jsloader/resource/gre/components/Weave.js <==
          resource:///components/Weave.js         
           u                                  ; 5   Q; 5  Q; 5  Q;  = : Q;  = 	: Q;  = 
: Q ; Y ;  
= : ] ;  Z  >; 5 ^?; 5 ^\: ]   \6 Q ; Y ;  
= : ] ;  Z  >; 5 ^?; 5 ^\: ]     \6 QZ  >; ^?; ^\ Q;  ; :  Q   &˸i&c3c3c3*cf	cf	cf	. 0cf	4c`ce7`>LNcf	Rc`ceUY`Egi0cf	3             Jb۬ӷe `              F  P   C c 
   C o m p o n e n t s    c l a s s e s      C i 
   i n t e r f a c e s    C u    u t i l s      i m p o r t %   r e s o u r c e : / / g r e / m o d u l e s / X P C O M U t i l s . j s m   #   r e s o u r c e : / / g r e / m o d u l e s / S e r v i c e s . j s m   $   r e s o u r c e : / / g r e / m o d u l e s / F i l e U t i l s . j s m    W e a v e S e r v i c e 	   p r o t o t y p e      I D &   { 7 4 b 8 9 f b 0 - f 2 0 0 - 4 a e 8 - a 3 e c - d d 1 6 4 1 1 7 f 6 d e }    c l a s s I D   
   X P C O M U t i l s 
   g e n e r a t e Q I    n s I O b s e r v e r      n s I S u p p o r t s W e a k R e f e r e n c e    Q u e r y I n t e r f a c e    o b s e r v e   
   A b o u t W e a v e L o g   &   { d 2 8 f 8 a 0 b - 9 5 d a - 4 8 f 4 - b 7 1 2 - c a f 3 7 0 9 7 b e 4 1 }    n s I A b o u t M o d u l e    g e t U R I F l a g s   
   n e w C h a n n e l 
   c o m p o n e n t s    N S G e t F a c t o r y    g e n e r a t e N S G e t F a c t o r y           W e a v e S e r v i c e                                                   AA6  Q b .        Jb۬ӷe `              F     w r a p p e d J S O b j e c t             B S S _ _ o b s e r v e 	              s u b j e c t      t o p i c      d a t a              ?                            T    G y    
  8;  5  ; 5 : W  QV   A= C: Q G  A;  5  	; 5 
: 6 QA5  Y     \X'; 5 
5 
: Q       ̐y ͸:cccc3c`  AdcfccacʸHfcc   ˰  7        Jb۬ӷe `              F  8   C c    @ m o z i l l a . o r g / o b s e r v e r - s e r v i c e ; 1   
   g e t S e r v i c e    C i    n s I O b s e r v e r S e r v i c e    a d d O b s e r v e r      f i n a l - u i - s t a r t u p    t i m e r      @ m o z i l l a . o r g / t i m e r ; 1    c r e a t e I n s t a n c e    n s I T i m e r    i n i t W i t h C a l l b a c k    n o t i f y 
   T Y P E _ O N E _ S H O T            o s         	          +                                        ;   = : Q; 5  :  ; 5  
; 5 Q cf	ccc	fc  C        Jb۬ӷe `              F     C u    i m p o r t     r e s o u r c e : / / s e r v i c e s - s y n c / m a i n . j s    W e a v e      S t a t u s 
   c h e c k S e t u p    C L I E N T _ N O T _ C O N F I G U R E D      S e r v i c e         a p p - s t a r t u p         f i n a l - u i - s t a r t u p        
   A b o u t W e a v e L o g                                                             N         Jb۬ӷe `              F   d        	              a U R I                                          >    U        Jb۬ӷe `              F  l        	             a U R I    d i r      u r i      c h a n n e l      s s m   	   p r i n c i p a l               6                           ;   = Z  >= ^?= ^\C: W  Q; 5  V  : W Q; 5  V : W QV T  6 	Q; 
5  ; 
5 : W QV  V : W QV V 6 QV    c`3 ccf3 ccf3 facccc3 cf	3 f   Y        Jb۬ӷe `              F  	   F i l e U t i l s      g e t D i r    P r o f D      w e a v e      l o g s    S e r v i c e s    i o 
   n e w F i l e U R I    n e w C h a n n e l F r o m U R I      o r i g i n a l U R I      C c $   @ m o z i l l a . o r g / s c r i p t s e c u r i t y m a n a g e r ; 1 
   g e t S e r v i c e    C i    n s I S c r i p t S e c u r i t y M a n a g e r    g e t C o d e b a s e P r i n c i p a l    o w n e r   
